==> haskell-bytestring-tree-builder-0.2.7.3-8-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-bytestring-tree-builder.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: bytestring-tree-builder
version: 0.2.7.3
id: bytestring-tree-builder-0.2.7.3-4jREFJFjrq6Ff1eqR7PrU8
key: bytestring-tree-builder-0.2.7.3-4jREFJFjrq6Ff1eqR7PrU8
license: MIT
copyright: (c) 2015, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/bytestring-tree-builder
synopsis: A very efficient ByteString builder implementation based on the binary tree
description:
    According to
    <https://github.com/nikita-volkov/bytestring-builders-benchmark the benchmarks>
    this builder implementation beats all the alternatives.
    It is especially well-suited for generating strict bytestrings,
    beating the standard builder by at least the factor of 4.
category: ByteString
abi: 8807df672f87064325f73b0ef539eb18
exposed: True
exposed-modules:
    ByteString.TreeBuilder
hidden-modules: ByteString.TreeBuilder.Prelude
                ByteString.TreeBuilder.Poker ByteString.TreeBuilder.Tree
import-dirs: /usr/lib/ghc-8.6.5/site-local/bytestring-tree-builder-0.2.7.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/bytestring-tree-builder-0.2.7.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/bytestring-tree-builder-0.2.7.3
hs-libraries: HSbytestring-tree-builder-0.2.7.3-4jREFJFjrq6Ff1eqR7PrU8
depends:
    base-4.12.0.0 base-prelude-1.3-4ZZNNsW3hao94Bjea11y2s
    bytestring-0.10.8.2 text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-bytestring-tree-builder/html/bytestring-tree-builder.haddock
haddock-html: /usr/share/doc/haskell-bytestring-tree-builder/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bytestring-tree-builder-0.2.7.3-9-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-bytestring-tree-builder.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: bytestring-tree-builder
version: 0.2.7.3
id: bytestring-tree-builder-0.2.7.3-EwZbSyu6vzxDDbMmeGykMw
key: bytestring-tree-builder-0.2.7.3-EwZbSyu6vzxDDbMmeGykMw
license: MIT
copyright: (c) 2015, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/bytestring-tree-builder
synopsis: A very efficient ByteString builder implementation based on the binary tree
description:
    According to
    <https://github.com/nikita-volkov/bytestring-builders-benchmark the benchmarks>
    this builder implementation beats all the alternatives.
    It is especially well-suited for generating strict bytestrings,
    beating the standard builder by at least the factor of 4.
category: ByteString
abi: 21ab367fe112b38accecb04c9d5d9bfb
exposed: True
exposed-modules:
    ByteString.TreeBuilder
hidden-modules: ByteString.TreeBuilder.Prelude
                ByteString.TreeBuilder.Poker ByteString.TreeBuilder.Tree
import-dirs: /usr/lib/ghc-8.6.5/site-local/bytestring-tree-builder-0.2.7.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/bytestring-tree-builder-0.2.7.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/bytestring-tree-builder-0.2.7.3
hs-libraries: HSbytestring-tree-builder-0.2.7.3-EwZbSyu6vzxDDbMmeGykMw
depends:
    base-4.12.0.0 base-prelude-1.3-4ZZNNsW3hao94Bjea11y2s
    bytestring-0.10.8.2 text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-bytestring-tree-builder/html/bytestring-tree-builder.haddock
haddock-html: /usr/share/doc/haskell-bytestring-tree-builder/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
